导入 sys
导入 os

sys.path.追加(os.路径.绝对路径(r'G:\grasspy_zwmodules\pysimplegui\zwpysimplegui\src'))

导入 快手

布局 = [  [快手.标签('5 - 1 = ')],      
          [快手.单选按钮('1', '答案', 大小=(5,1)), 快手.单选按钮('2', '答案', 大小=(5,1)), 
            快手.单选按钮('3', '答案', 大小=(5,1)), 快手.单选按钮('4', '答案', 大小=(5,1))],      
          [快手.按钮('重做'), 快手.按钮('提交')]  ]      

窗口 = 快手.窗口类('选择题', 布局)

只要 真:                             # 事件循环
    事件, 值 = 窗口.读取() 
    打印(事件, 值)       
    如果 事件 == 空 或 事件 == '提交':  # 退出窗口事件
        跳出      

窗口.关闭()

